@@ -23,7 +23,7 @@ import six
 
 from pymatgen.serializers.json_coders import PMGSONable
 from pymatgen.analysis.ewald import EwaldSummation
-from pymatgen.symmetry.finder import SymmetryFinder
+from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
 
 class EnergyModel(six.with_metaclass(abc.ABCMeta, PMGSONable)):
@@ -96,7 +96,7 @@ class SymmetryModel(EnergyModel):
     lower "energy".
 
     Args have same meaning as in
-    :class:`pymatgen.symmetry.finder.SymmetryFinder`.
+    :class:`pymatgen.symmetry.finder.SpacegroupAnalyzer`.
 
     Args:
         symprec (float): Symmetry tolerance. Defaults to 0.1.
@@ -108,7 +108,7 @@ class SymmetryModel(EnergyModel):
         self.angle_tolerance = angle_tolerance
 
     def get_energy(self, structure):
-        f = SymmetryFinder(structure, symprec=self.symprec,
+        f = SpacegroupAnalyzer(structure, symprec=self.symprec,
                            angle_tolerance=self.angle_tolerance)
         return -f.get_spacegroup_number()
 
