@@ -1,16 +1,16 @@
-from __future__ import division, print_function
-
+# coding: utf-8
 """
 This module defines the events signaled by abinit during the execution. It also
 provides a parser to extract these events form the main output file and the log file.
 """
+from __future__ import unicode_literals, division, print_function
 
 import os.path
 import collections
 import yaml
 
 from pymatgen.util.string_utils import WildCard
-from pymatgen.io.abinitio.abiinspect import YamlTokenizer
+from .abiinspect import YamlTokenizer
 
 __all__ = [
     "EventsParser",
