@@ -1007,7 +1007,8 @@ class QcTask(PMGSONable):
             else:
                 ghost_atoms, coord_lines = parse_ghost_indices(contents[1:])
                 mol = cls._parse_coords(coord_lines)
-                mol.set_charge_and_spin(charge, spin_multiplicity)
+                if len(ghost_atoms) == 0:
+                    mol.set_charge_and_spin(charge, spin_multiplicity)
             ghost_atoms = ghost_atoms if len(ghost_atoms) > 0 else None
             return mol, charge, spin_multiplicity, ghost_atoms
 
@@ -1603,7 +1604,8 @@ class QcOutput(object):
             errors.append("Molecular spin multipilicity is not found")
         else:
             for mol in molecules:
-                mol.set_charge_and_spin(charge, spin_multiplicity)
+                if qctask is None or qctask.ghost_atoms is None:
+                    mol.set_charge_and_spin(charge, spin_multiplicity)
         for k in thermal_corr.keys():
             v = thermal_corr[k]
             if "Entropy" in k:
