@@ -1,6 +1,6 @@
 # coding: utf-8
 
-from __future__ import division, unicode_literals
+from __future__ import division, unicode_literals, print_function
 
 """
 Classes for reading/manipulating/writing VASP ouput files.
@@ -32,7 +32,7 @@ from six.moves import map, zip
 
 import numpy as np
 
-from monty.io import zopen, reverse_readline
+from monty.io import zopen, reverse_readfile
 
 from pymatgen.util.io_utils import clean_lines, micro_pyawk, \
     clean_json
@@ -936,78 +936,87 @@ class Outcar(PMGSONable):
     def __init__(self, filename):
         self.filename = filename
         self.is_stopped = False
-        with zopen(filename, "rt") as f:
-            read_charge_mag = False
-            charge = []
-            mag = []
-            header = []
-            run_stats = {}
-            total_mag = None
-            nelect = None
-            efermi = None
 
-            time_patt = re.compile("\((sec|kb)\)")
-            efermi_patt = re.compile("E-fermi\s*:\s*(\S+)")
-            nelect_patt = re.compile("number of electron\s+(\S+)\s+"
-                                     "magnetization\s+(\S+)")
-            all_lines = []
-            for line in reverse_readline(f):
-                clean = line.strip()
-                all_lines.append(clean)
-                if clean.startswith("tot ") and not (charge and mag):
-                    read_charge_mag = True
-                    data = []
-                elif read_charge_mag:
-                    if clean.startswith("# of ion"):
-                        header = re.split("\s{2,}", line.strip())
-                        header.pop(0)
-                    elif clean == "total charge":
-                        data.reverse()
-                        charge = [dict(zip(header, v)) for v in data]
-                        read_charge_mag = False
-                    elif clean == "magnetization (x)":
-                        data.reverse()
-                        mag = [dict(zip(header, v)) for v in data]
-                        read_charge_mag = False
-                    else:
-                        m = re.match("\s*(\d+)\s+(([\d\.\-]+)\s+)+", clean)
-                        if m:
-                            toks = [float(i) for i in re.findall("[\d\.\-]+",
-                                                                 clean)]
-                            toks.pop(0)
-                            data.append(toks)
-                elif clean.find("soft stop encountered!  aborting job") != -1:
-                    self.is_stopped = True
+        # data from end of OUTCAR
+        read_charge_mag = False
+        charge = []
+        mag = []
+        header = []
+        run_stats = {}
+        total_mag = None
+        nelect = None
+        efermi = None
+
+        time_patt = re.compile("\((sec|kb)\)")
+        efermi_patt = re.compile("E-fermi\s*:\s*(\S+)")
+        nelect_patt = re.compile("number of electron\s+(\S+)\s+"
+                                 "magnetization\s+(\S+)")
+        all_lines = []
+        for line in reverse_readfile(self.filename):
+            clean = line.strip()
+            all_lines.append(clean)
+            if clean.startswith("tot ") and not (charge and mag):
+                read_charge_mag = True
+                data = []
+            elif read_charge_mag:
+                if clean.startswith("# of ion"):
+                    header = re.split("\s{2,}", line.strip())
+                    header.pop(0)
+                elif clean == "total charge":
+                    data.reverse()
+                    charge = [dict(zip(header, v)) for v in data]
+                    read_charge_mag = False
+                elif clean == "magnetization (x)":
+                    data.reverse()
+                    mag = [dict(zip(header, v)) for v in data]
+                    read_charge_mag = False
                 else:
-                    if time_patt.search(line):
-                        tok = line.strip().split(":")
-                        run_stats[tok[0].strip()] = float(tok[1].strip())
+                    m = re.match("\s*(\d+)\s+(([\d\.\-]+)\s+)+", clean)
+                    if m:
+                        toks = [float(i) for i in re.findall("[\d\.\-]+",
+                                                             clean)]
+                        toks.pop(0)
+                        data.append(toks)
+            elif clean.find("soft stop encountered!  aborting job") != -1:
+                self.is_stopped = True
+                #print(clean, cores)
+            else:
+                if time_patt.search(line):
+                    tok = line.strip().split(":")
+                    run_stats[tok[0].strip()] = float(tok[1].strip())
+                    continue
+                m = efermi_patt.search(clean)
+                if m:
+                    try:
+                        #try-catch because VASP sometimes prints
+                        #'E-fermi: ********     XC(G=0):  -6.1327
+                        #alpha+bet : -1.8238'
+                        efermi = float(m.group(1))
                         continue
-                    m = efermi_patt.search(clean)
-                    if m:
-                        try:
-                            #try-catch because VASP sometimes prints
-                            #'E-fermi: ********     XC(G=0):  -6.1327
-                            #alpha+bet : -1.8238'
-                            efermi = float(m.group(1))
-                            continue
-                        except ValueError:
-                            efermi = None
-                            continue
-                    m = nelect_patt.search(clean)
-                    if m:
-                        nelect = float(m.group(1))
-                        total_mag = float(m.group(2))
-                if all([nelect, total_mag is not None, efermi is not None,
-                        run_stats]):
+                    except ValueError:
+                        efermi = None
+                        continue
+                m = nelect_patt.search(clean)
+                if m:
+                    nelect = float(m.group(1))
+                    total_mag = float(m.group(2))
+            if all([nelect, total_mag is not None, efermi is not None,
+                    run_stats]):
+                break
+
+        # data from beginning of OUTCAR
+        with zopen(filename, "rt") as f:
+            for line in f:
+                if "running" in line:
+                    run_stats['cores'] = line.split()[2]
                     break
 
-            self.run_stats = run_stats
-            self.magnetization = tuple(mag)
-            self.charge = tuple(charge)
-            self.efermi = efermi
-            self.nelect = nelect
-            self.total_mag = total_mag
+        self.run_stats = run_stats
+        self.magnetization = tuple(mag)
+        self.charge = tuple(charge)
+        self.efermi = efermi
+        self.nelect = nelect
+        self.total_mag = total_mag
 
     def read_igpar(self):
         """
